import axios from "axios";
export class RequestBuilder {
    constructor(comand, defaultOpt = {}, defautArgs = {}) {
        this.command = comand;
        this.args = defautArgs;
        this.options = defaultOpt;
    }
    option(key, value) {
        this.options[key] = value;
        return this;
    }
    arg(key, value) {
        this.args[key] = value;
        return this;
    }
    static new(comand, defaultOpt = {}, defautArgs = {}) {
        return new RequestBuilder(comand, defaultOpt, defautArgs);
    }
}
export class KuboClient {
    constructor(config = {}) {
        this.config = {
            protocol: "http",
            host: "127.0.0.1",
            port: 5001,
            apiPath: "/api/v0",
        };
        this.config = { ...this.config, ...config };
    }
    getUrl(command) {
        return `${this.config.protocol}://${this.config.host}:${this.config.port}${this.config.apiPath}/${command}`;
    }
    async exist(path) {
        try {
            await this.filesStat({ arg: path });
            return true;
        }
        catch (e) {
            return false;
        }
    }
    async existFile(path) {
        try {
            const result = await this.filesStat({ arg: path });
            return result.Type === "file";
        }
        catch (e) {
            return false;
        }
    }
    async existDir(path) {
        try {
            const result = await this.filesStat({ arg: path });
            return result.Type === "directory";
        }
        catch (e) {
            return false;
        }
    }
    async filesLs(args = { path: "/" }) {
        const { Entries } = await this.execute(new RequestBuilder("files/ls", {}, args));
        return Entries;
    }
    async filesStat(args = { arg: "/" }) {
        return this.execute(new RequestBuilder("files/stat", {}, args));
    }
    async filesRm(args) {
        await this.execute(new RequestBuilder("files/rm", {}, args));
    }
    async filesAdd(filename, filecontent) {
        const fileForm = new FormData();
        fileForm.append("file", new Blob([filecontent]), filename);
        return this.execute(new RequestBuilder("add", fileForm, {}), {
            "Content-Type": "multipart/form-data",
        });
    }
    async filesCp(src, dst) {
        return this.execute(new RequestBuilder(`files/cp?arg=${src}&arg=${dst}&parents=true`));
    }
    async filesMkdir(args) {
        return this.execute(new RequestBuilder("files/mkdir", {}, args));
    }
    async filesWrite(path, content) {
        const filename = path.split("/").pop();
        const addResult = await this.filesAdd(filename, content);
        return this.filesCp(`/ipfs/${addResult.Hash}`, path);
    }
    async filesRead(args = {}) {
        return new TextEncoder().encode(await this.execute(new RequestBuilder("files/read", {}, args)));
    }
    async pinAdd(args) {
        return this.execute(new RequestBuilder("pin/add", {}, args));
    }
    async namePublish(arg) {
        const path = typeof arg === "undefined"
            ? `/ipfs/${(await this.filesStat({ arg: "/" })).Hash}`
            : arg;
        return this.execute(new RequestBuilder("name/publish", {}, { arg: path }));
    }
    async nameResolve(arg) {
        return this.execute(new RequestBuilder("name/resolve", {}, { arg }));
    }
    async keyList() {
        return (await this.execute(new RequestBuilder("key/list")))
            .Keys;
    }
    async execute(requestBuilder, configHeaders = {}) {
        const headers = {
            ...{ "Content-Type": "application/json" },
            ...configHeaders,
        };
        const res = await axios.post(this.getUrl(requestBuilder.command), requestBuilder.options, {
            params: requestBuilder.args,
            headers,
        });
        return res.data;
    }
}
//# sourceMappingURL=index.js.map